@@ -10,13 +10,35 @@ from geostore.models import Feature, LayerRelation
 logger = logging.getLogger(__name__)
 
 
+class ConcurrentPropertyModificationError(Exception):
+    """
+    This exception is raised when an instance property field is being modified concurrently by two processes
+    It means that a data race is happening. Maybe your property field should be marked as read-only ?
+    """
+
+    pass
+
+
 def compute_properties(instance, prop):
     value = import_string(prop.function_path)(instance)
     old_value = instance.properties.get(prop.key)
+
+    # Since this function is called in an async context, the 'properties' field might have been modified during our
+    # computation. To avoid data loss we fetch the latest version of the dict and handle conflicting modifications.
+    instance.refresh_from_db()
+
+    value_from_db = instance.properties.get(prop.key)
+    if value_from_db != old_value:
+        raise ConcurrentPropertyModificationError(
+            "A property has been modified while a computation was going on. Computed "
+            "properties should be non-editable, check your configuration."
+        )
+
     instance.properties[prop.key] = value
     try:
         instance.clean()
-        instance.save(update_fields=['properties'])
+        # Avoiding signal post_save again
+        Feature.objects.bulk_update([instance], ['properties'])
     except ValidationError:
         logger.warning("The function to update property didn't give the good format, "
                        "fix your function or the schema")
@@ -36,37 +58,45 @@ def change_props(feature):
 def feature_update_relations_origins(features_id, kwargs):
     features = Feature.objects.filter(pk__in=features_id)
     for feature in features:
-        feature_update_relations_destinations.delay(feature.pk, kwargs)
+        feature_update_relations_and_properties.delay(feature.pk, kwargs)
 
     return True
 
 
-def sync_relations_destination(feature, kwargs):
+def sync_properties_relations_destination(feature, update_relations=False):
     for relation_destination in feature.layer.relations_as_destination.all():
         for feature in relation_destination.origin.features.all():
-            feature.sync_relations(kwargs['relation_id'])
-            change_props(feature)
+            if update_relations:
+                feature.sync_relations(relation_destination.pk)
+            change_props(feature)  # TODO:  Compute link between relation and computed properties
 
 
 @shared_task
-def feature_update_relations_destinations(feature_id, kwargs):
+def feature_update_relations_and_properties(feature_id, kwargs):
     """ Update all feature layer relations """
     try:
         feature = Feature.objects.get(pk=feature_id)
     except Feature.DoesNotExist:
         return False
+    feature.sync_relations(None)
 
-    if (kwargs.get('update_fields') is None or 'properties' not in kwargs.get('update_fields')) and hasattr(
-            feature.layer, 'crud_view'):
-        feature.sync_relations(kwargs['relation_id'])
+    sync_properties_relations_destination(feature, update_relations=True)
 
-        sync_relations_destination(feature, kwargs)
-
-        change_props(feature)
+    change_props(feature)
 
     return True
 
 
+@shared_task
+def feature_update_destination_properties(feature_id, kwargs):
+    try:
+        feature = Feature.objects.get(pk=feature_id)
+    except Feature.DoesNotExist:
+        return False
+
+    sync_properties_relations_destination(feature)
+
+
 @shared_task
 def layer_relations_set_destinations(relation_id):
     """ Update all feature layer as origin for a relation """
@@ -77,6 +107,6 @@ def layer_relations_set_destinations(relation_id):
 
     kwargs = {"relation_id": relation_id}
     for feature_id in relation.origin.features.values_list('pk', flat=True):
-        feature_update_relations_destinations.delay(feature_id, kwargs)
+        feature_update_relations_and_properties.delay(feature_id, kwargs)
 
     return True
